sublime-info changelog
======================
0.2.0 - Added Python 3 support via @adambullmer in #5. Fixes #4

0.1.3 - Repaired Travis CI

0.1.2 - Added foundry for release

0.1.1 - Fix for README in PyPI

0.1.0 - Initial release

0.0.3 - Added support for package directory

0.0.2 - Added support for build number

0.0.1 - Resolving Sublime in multiple forms
